# Patching guideline for python :
# - no big patch with invasive change not 
#     approved by upstream ( ie not coming from upstream svn )
# - small bugfix must be sent to upstream and approved if they 
#     change any interface
# - all patchs should be commented ( unless for security, 
#     as they are usually easy to spot )

%define docver  2.7.5
%define dirver  2.7

%define lib_major       %{dirver}
%define lib_name_orig   libpython
%define lib_name        %mklibname %{name} %{lib_major}
%define dev_name        %mklibname %{name} -d

%define arch_has_valgrind 1
%ifarch %arm %mips
%define arch_has_valgrind 0
%endif

%if %arch_has_valgrind
%bcond_without  valgrind
%else
%bcond_with     valgrind
%endif

# Some of the files below /usr/lib/pythonMAJOR.MINOR/test  (e.g. bad_coding.py)
# are deliberately invalid, leading to SyntaxError exceptions if they get
# byte-compiled.
#
# These errors are ignored by the normal python build, and aren't normally a
# problem in the buildroots since /usr/bin/python isn't present.
# 
# So we disable here brp-python-bytecompile
#
%define _python_bytecompile_build 0


Summary:        An interpreted, interactive object-oriented programming language
Name:           python
Version:        2.7.5
Release:        %mkrel 11
License:        Modified CNRI Open Source License
Group:          Development/Python
Url:            http://www.python.org/

Source0:        http://www.python.org/ftp/python/%{version}/Python-%{version}.tar.xz
Source1:        http://www.python.org/ftp/python/doc/%{docver}/python-%{docver}-docs-html.tar.bz2
Source4:        python-mode-1.0.tar.bz2
Patch0:         python-2.7.5-module-linkage.patch
# Don't include /usr/local/* in search path
Patch3:         Python-2.7.5-no-local-incpath.patch

# Support */lib64 convention on x86_64, sparc64, etc.
# similar patches reported upstream on http://bugs.python.org/issue1294959
Patch4:         python-lib64.patch

# Do handle <asm-XXX/*.h> headers in h2py.py
# FIXME: incomplete for proper bi-arch support as #if/#else/#endif
# clauses generally should have been handled
# to send upstream after cleaning
Patch5:         Python-2.2.2-biarch-headers.patch

# add mandriva to the list of supported distribution, applied upstream
Patch10:        python-2.5.1-detect-mandriva.patch

# from Fedora, fixes gettext.py parsing of Plural-Forms: header (fixes mdv bugs #49475, #44088)
# to send upstream
Patch16:        python-2.5.1-plural-fix.patch

# ffi checks for MIPS_LINUX instead of MIPS
Patch23:        python-2.7-mips-ffi.patch

# do not use uname -m to get the exact name on mips/arm
Patch24:        python_arch.patch

# fix https://bugs.mageia.org/show_bug.cgi?id=481
# mdv bug #62281 
# patch to cope with lack of /dev/shm in iurt 
Patch25:        python-2.7.5-skip-shm-test.patch 

Patch130:       Python-2.7.5-check-for-XML_SetHashSalt.diff

# 00173 #
# Workaround for ENOPROTOOPT seen in bs within
# test.test_support.bind_port()
# from Fedora (rhbz#913732)
Patch173:       00173-workaround-ENOPROTOOPT-in-bind_port.patch

# upstream:
# fix CVE-2013-4073
# http://bugs.python.org/file31243/CVE-2013-4073_py27.patch
Patch174:   Python-2.7.3-CVE-2013-4073.diff

Conflicts:      tkinter < %{version}
Conflicts:      python-devel < 2.7-6
Requires:       %{lib_name} = %{version}
BuildRequires:  blt
BuildRequires:  db5-devel
BuildRequires:  emacs-bin
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(libffi)
BuildRequires:  gdbm-devel
BuildRequires:  gmp-devel
BuildRequires:  ncursesw-devel
BuildRequires:  openssl-devel
BuildRequires:  readline-devel
BuildRequires:  termcap-devel
BuildRequires:  tk-devel
BuildRequires:  tix
BuildRequires:  autoconf2.5
BuildRequires:  bzip2-devel
BuildRequires:  sqlite3-devel
BuildRequires:  emacs
%if %{with valgrind}
BuildRequires:  valgrind-devel
%endif

# (2010/03/21, misc: interfere with test__all )
BuildConflicts: python-pyxml

Provides:       python(abi) = %dirver
%rename python-ctypes
%rename python-elementtree
Obsoletes:      python-base < 2.6
Provides:       python-base = %version

%description
Python is an interpreted, interactive, object-oriented programming
language often compared to Tcl, Perl, Scheme or Java. Python includes
modules, classes, exceptions, very high level dynamic data types and
dynamic typing. Python supports interfaces to many system calls and
libraries, as well as to various windowing systems (X11, Motif, Tk,
Mac and MFC).

Programmers can write new built-in modules for Python in C or C++.
Python can be used as an extension language for applications that
need a programmable interface. This package contains most of the
standard Python modules, as well as modules for interfacing to the
Tix widget set for Tk and RPM.

Note that documentation for Python is provided in the python-docs
package.

%package -n     %{lib_name}
Summary:        Shared libraries for Python %{version}
Group:          System/Libraries

%description -n %{lib_name}
This packages contains Python shared object library.  Python is an
interpreted, interactive, object-oriented programming language often
compared to Tcl, Perl, Scheme or Java.

%package -n     %{dev_name}
Summary:        The libraries and header files needed for Python development
Group:          Development/Python
Requires:       %{name} = %version
Requires:       %{lib_name} = %{version}
Obsoletes:      %{name}-devel < %{version}
# (misc) needed to ease upgrade , see #47803
Obsoletes:      %mklibname -d %{name} 2.5
Obsoletes:      %mklibname -d %{name} 2.6
Obsoletes:      %{mklibname -d %{name} 2.7} < 2.7-4
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{lib_name_orig}-devel = %{version}-%{release}

%description -n %{dev_name}
The Python programming language's interpreter can be extended with
dynamically loaded extensions and can be embedded in other programs.
This package contains the header files and libraries needed to do
these types of tasks.

Install %{dev_name} if you want to develop Python extensions.  The
python package will also need to be installed.  You'll probably also
want to install the python-docs package, which contains Python
documentation.

%package        docs
Summary:        Documentation for the Python programming language
Requires:       python = %version
Requires:       xdg-utils
Group:          Development/Python
BuildArch:      noarch

%description    docs
The python-docs package contains documentation on the Python
programming language and interpreter.  The documentation is provided
in ASCII text files and in LaTeX source files.

Install the python-docs package if you'd like to use the documentation
for the Python language.

%package -n     tkinter
Summary:        A graphical user interface for the Python scripting language
Group:          Development/Python
Requires:       python = %version
Requires:       tcl tk

%description -n tkinter
The Tkinter (Tk interface) program is an graphical user interface for
the Python scripting language.

You should install the tkinter package if you'd like to use a graphical
user interface for Python programming.

%package -n     tkinter-apps
Summary:        Various applications written using tkinter
Group:          Development/Python
Requires:       tkinter

%description -n tkinter-apps
Various applications written using tkinter

%prep
%setup -q -n Python-%{version}
%patch0 -p0
# local include
%patch3 -p0
# lib64
%patch4 -p0 -b .lib64

# biarch header
%patch5 -p0

# add mandriva to the list of supported distribution
%patch10 -p0


%patch16 -p1 -b .plural-fix

%patch23 -p1 -b .mips
%patch24 -p1 -b .arch
%patch25 -p1
%patch130 -p1 -b .check-for-XML_SetHashSalt
%patch173 -p1
%patch174 -p1 -b .CVE-2013-4073

autoconf

mkdir html
bzcat %{SOURCE1} | tar x  -C html
find html -type d |xargs chmod 755
find html -type f |xargs chmod 644

find . -type f -print0 | xargs -0 perl -p -i -e 's@/usr/local/bin/python@/usr/bin/python@'

tar --strip-components=1 -xjf %{SOURCE4} -C Misc

cat > README.mga << EOF
Python interpreter support readline completion by default.
This is only used with the interpreter. In order to remove it,
you can :
1) unset PYTHONSTARTUP when you login
2) create a empty file \$HOME/.pythonrc.py
3) change %{_sysconfdir}/pythonrc.py
EOF
# make sur the IN.py TYPES.py and DLFCN.py are correct
# for current arch otherwise things will start failing
# in weird ways
pushd Lib/plat-linux2/
../../Tools/scripts/h2py.py -i '(u_long)' /usr/include/sys/types.h /usr/include/netinet/in.h /usr/include/dlfcn.h
popd

%build
rm -f Modules/Setup.local
cat > Modules/Setup.local << EOF
linuxaudiodev linuxaudiodev.c
EOF

OPT="$RPM_OPT_FLAGS -g"
export OPT

# to fix curses module build
# https://bugs.mageia.org/show_bug.cgi?id=5524
export CFLAGS="%{optflags} -I/usr/include/ncursesw"
export CPPFLAGS="%{optflags} -I/usr/include/ncursesw"
# Remove -Wl,--no-undefined in accordance with MGA #9395 and MGA #10102:
# https://bugs.mageia.org/show_bug.cgi?id=9395
# https://bugs.mageia.org/show_bug.cgi?id=10102
%define _disable_ld_no_undefined 1

# see https://qa.mandriva.com/show_bug.cgi?id=48570 
# for wide unicode support
%configure2_5x  --with-threads \
        --enable-unicode=ucs4 \
        --with-dbmliborder=gdbm \
        --enable-ipv6 \
        --enable-shared \
        --with-system-expat \
        --with-system-ffi \
%if %{with valgrind}
        --with-valgrind
%endif

# fix build
#perl -pi -e 's/^(LDFLAGS=.*)/$1 -lstdc++/' Makefile
# (misc) if the home is nfs mounted, rmdir fails due to delay
export TMP="/tmp" TMPDIR="/tmp"
make

%check
# (misc) if the home is nfs mounted, rmdir fails
export TMP="/tmp" TMPDIR="/tmp"

# all tests must pass
%ifarch %arm
# don't know if it's a python issue or a toolchain issue :(
# test test_float failed -- Traceback (most recent call last):
#  File "/home/rtp/deb/python2.6-2.6.4/Lib/test/test_float.py", line 665, in test_from_hex
#    self.identical(fromHex('0x0.ffffffffffffd6p-1022'), MIN-3*TINY)
#  File "/home/rtp/deb/python2.6-2.6.4/Lib/test/test_float.py", line 375, in identical
#    self.fail('%r not identical to %r' % (x, y))
# AssertionError: 2.2250738585071999e-308 not identical to 2.2250738585071984e-308
%define custom_test -x test_float
%else
%define custom_test ""
%endif 
# if a test doesn't pass, it can be disabled with -x test, but this should be documented in the
# spec file, and a bug should be reported if possible ( on python side )
# (misc, 28/10/2010) test_gdb fail, didn't time too look
# (misc, 29/10/2010) test_site fail due to one of our patch, will fix later
#   test_distutils, fail because of lib64 patch ( like test_site ), and because it requires libpython2.7 to be installed
#   test_io, blocks on my computer on 2nd run
# (misc, 22/05/2011) test_urllib2 fail, related to CVE-2011-1521 :
# test test_urllib2 failed -- Traceback (most recent call last):
#  File "/home/iurt/rpm/BUILD/Python-2.7.1/Lib/test/test_urllib2.py", line 990, in test_invalid_redirect
#    MockHeaders({"location": valid_url}))
#  File "/home/iurt/rpm/BUILD/Python-2.7.1/Lib/urllib2.py", line 617, in http_error_302
#    return self.parent.open(new, timeout=req.timeout)
#  File "/home/iurt/rpm/BUILD/Python-2.7.1/Lib/urllib2.py", line 219, in __getattr__
#    raise AttributeError, attr
# AttributeError: timeout

WITHIN_PYTHON_RPM_BUILD= make test TESTOPTS="-w -l -x test_gdb -x test_site -x test_io -x test_distutils -x test_urllib2 %custom_test"

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p %buildroot%{_prefix}/lib/python%{dirver}

# fix Makefile to get rid of reference to distcc
perl -pi -e "/^CC=/ and s/distcc/gcc/" Makefile

# set the install path
echo '[install_scripts]' >setup.cfg
echo 'install_dir='"${RPM_BUILD_ROOT}/usr/bin" >>setup.cfg

# python is not GNU and does not know fsstd
mkdir -p $RPM_BUILD_ROOT%{_mandir}
%makeinstall_std

(cd $RPM_BUILD_ROOT%{_libdir}; ln -sf libpython%{lib_major}.so.* libpython%{lib_major}.so)

# Provide a libpython%{dirver}.so symlink in /usr/lib/puthon*/config, so that
# the shared library could be found when -L/usr/lib/python*/config is specified
(cd $RPM_BUILD_ROOT%{_libdir}/python%{dirver}/config; ln -sf ../../libpython%{lib_major}.so .)

# emacs, I use it, I want it
mkdir -p $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp
install -m 644 Misc/python-mode.el $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp
emacs -batch -f batch-byte-compile $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp/python-mode.el

install -d $RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d
cat <<EOF >$RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d/%{name}.el
(setq auto-mode-alist (cons '("\\\\.py$" . python-mode) auto-mode-alist))
(autoload 'python-mode "python-mode" "Mode for python files." t)
EOF

#"  this comment is just here because vim syntax higlighting is confused by the previous snippet of lisp

# smtpd proxy
mv -f $RPM_BUILD_ROOT%{_bindir}/smtpd.py $RPM_BUILD_ROOT%{_libdir}/python%{dirver}/

# idle
cp Tools/scripts/idle $RPM_BUILD_ROOT%{_bindir}/idle


# pynche
cat << EOF > $RPM_BUILD_ROOT%{_bindir}/pynche
#!/bin/bash
exec %{_libdir}/python%{dirver}/site-packages/pynche/pynche
EOF
rm -f Tools/pynche/*.pyw
cp -r Tools/pynche $RPM_BUILD_ROOT%{_libdir}/python%{dirver}/site-packages/

chmod 755 $RPM_BUILD_ROOT%{_bindir}/{idle,pynche}

ln -f Tools/pynche/README Tools/pynche/README.pynche

%if %{with valgrind}
install Misc/valgrind-python.supp -D $RPM_BUILD_ROOT%{_libdir}/valgrind/valgrind-python.supp
%endif

mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
cat > $RPM_BUILD_ROOT%{_datadir}/applications/%{_real_vendor}-tkinter.desktop << EOF
[Desktop Entry]
Name=IDLE
Comment=IDE for Python
Exec=%{_bindir}/idle
Icon=development_environment_section
Terminal=false
Type=Application
Categories=Development;IDE;
EOF


cat > $RPM_BUILD_ROOT%{_datadir}/applications/%{_real_vendor}-%{name}-docs.desktop << EOF
[Desktop Entry]
Name=Python documentation
Comment=Python complete reference
Exec=%{_bindir}/xdg-open %_defaultdocdir/%{name}-docs/index.html
Icon=documentation_section
Terminal=false
Type=Application
Categories=Documentation;
EOF


# fix non real scripts
chmod 644 $RPM_BUILD_ROOT%{_libdir}/python*/test/test_{binascii,grp,htmlparser}.py*
# fix python library not stripped
chmod u+w $RPM_BUILD_ROOT%{_libdir}/libpython%{lib_major}.so.1.0


mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/

cat > $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/30python2.sh << 'EOF'
if [ -f $HOME/.pythonrc.py ] ; then
        export PYTHONSTARTUP=$HOME/.pythonrc.py
else
        export PYTHONSTARTUP=/etc/pythonrc.py
fi
EOF

cat > $RPM_BUILD_ROOT/%{_sysconfdir}/profile.d/30python2.csh << 'EOF'
if ( -f ${HOME}/.pythonrc.py ) then
        setenv PYTHONSTARTUP ${HOME}/.pythonrc.py
else
        setenv PYTHONSTARTUP /etc/pythonrc.py
endif
EOF

cat > $RPM_BUILD_ROOT%{_sysconfdir}/pythonrc.py << EOF
try:
    # this add completion to python interpreter
    import readline
    import rlcompleter
    # see readline man page for this
    readline.parse_and_bind("set show-all-if-ambiguous on")
    readline.parse_and_bind("tab: complete")
except:
    pass
# you can place a file .pythonrc.py in your home to overrides this one
# but then, this file will not be sourced
EOF

%multiarch_includes $RPM_BUILD_ROOT/usr/include/python*/pyconfig.h

%files
%doc README.mga
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/%{name}.el
%config(noreplace) %{_sysconfdir}/profile.d/30python2.*
%config(noreplace) %{_sysconfdir}/pythonrc.py
# "Makefile" and the config.h file are needed by
# distutils/sysconfig.py:_init_posix(), so we include them in the libs
# package, along with their parent directories (RH bug#531901):
%dir %{_libdir}/python%{dirver}/config
%{_libdir}/python%{dirver}/config/Makefile
%dir %{_includedir}/python%{dirver}
%{_includedir}/python%{dirver}/pyconfig.h
%multiarch %multiarch_includedir/python%{dirver}/pyconfig.h

%exclude %{_libdir}/python%{dirver}/config/Setup
%exclude %{_libdir}/python%{dirver}/config/Setup.config
%exclude %{_libdir}/python%{dirver}/config/Setup.local
%exclude %{_libdir}/python%{dirver}/config/config.c
%exclude %{_libdir}/python%{dirver}/config/config.c.in
%exclude %{_libdir}/python%{dirver}/config/install-sh
%exclude %{_libdir}/python%{dirver}/config/libpython2.7.a
%exclude %{_libdir}/python%{dirver}/config/libpython2.7.so
%exclude %{_libdir}/python%{dirver}/config/makesetup
%exclude %{_libdir}/python%{dirver}/config/python.o
%exclude %{_libdir}/python%{dirver}/test/
%exclude %{_libdir}/python%{dirver}/idlelib
%exclude %{_libdir}/python%{dirver}/lib-tk
%exclude %{_libdir}/python%{dirver}/lib-dynload/_tkinter.so
%exclude %{_libdir}/python%{dirver}/site-packages/pynche

%{_libdir}/python%{dirver}
%if "%{_lib}" != "lib"
%{_prefix}/lib/python%{dirver}
%endif
%{_bindir}/python2
%{_bindir}/python%{dirver}
%{_bindir}/pydoc
%{_bindir}/python
%{_bindir}/2to3
%{_datadir}/emacs/site-lisp/*
%{_mandir}/man*/*
%if %{with valgrind}
%{_libdir}/valgrind/valgrind-python.supp
%endif

%files -n %{lib_name}
%{_libdir}/libpython*.so.1*

%files -n %{dev_name}
%{_libdir}/libpython*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/python%{dirver}
%{_libdir}/python%{dirver}/config/*
%{_libdir}/python%{dirver}/test/
%{_bindir}/python%{dirver}-config
%{_bindir}/python-config
%{_bindir}/python2-config
%exclude %{_libdir}/python%{dirver}/config/Makefile
%exclude %{_includedir}/python%{dirver}/pyconfig.h

%files docs
%doc html/*/*
%{_datadir}/applications/%{_real_vendor}-%{name}-docs.desktop

%files -n tkinter
%dir %{_libdir}/python%{dirver}/lib-tk
%{_libdir}/python%{dirver}/lib-tk/*.py*
%{_libdir}/python%{dirver}/lib-tk/test/
%{_libdir}/python%{dirver}/lib-dynload/_tkinter.so
%{_libdir}/python%{dirver}/idlelib
%{_libdir}/python%{dirver}/site-packages/pynche

%files -n tkinter-apps
%{_bindir}/idle
%{_bindir}/pynche
%{_datadir}/applications/%{_real_vendor}-tkinter.desktop




%changelog
* Tue Oct 22 2013 umeabot <umeabot> 2.7.5-11.mga4
+ Revision: 545491
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.7.5-10.mga4
+ Revision: 498057
- Rebuild to add different pythonegg provides for python 2 and 3

* Thu Sep 26 2013 fwang <fwang> 2.7.5-9.mga4
+ Revision: 486490
- drop conflicts could not be satisfied

* Wed Sep 25 2013 philippem <philippem> 2.7.5-8.mga4
+ Revision: 486298
+ rebuild (emptylog)

* Wed Sep 25 2013 fwang <fwang> 2.7.5-7.mga4
+ Revision: 485888
- versioned obsoletes

* Wed Sep 25 2013 fwang <fwang> 2.7.5-6.mga4
+ Revision: 485866
- add conflicts to ease upgrade

* Tue Sep 24 2013 philippem <philippem> 2.7.5-5.mga4
+ Revision: 485674
- remove PYTHONDONTWRITEBYTECODE=1 fix mga#3348
- profile.d files as configfile noreplace fix mga#10758

* Mon Aug 12 2013 oden <oden> 2.7.5-4.mga4
+ Revision: 465654
- P174: security fix for CVE-2013-4073 (upstream)

* Wed Jun 26 2013 philippem <philippem> 2.7.5-3.mga4
+ Revision: 447236
- Convert inconsistent indentation to spaces only to be in synch with python3 package

* Tue Jun 25 2013 philippem <philippem> 2.7.5-2.mga4
+ Revision: 446643
- Remove -Wl,--no-undefined in accordance with MGA #9395 and MGA #10102
- Remove -Wl,--no-undefined in Makefile in accordance with MGA #9395 and MGA #10102

* Tue May 28 2013 tv <tv> 2.7.5-1.mga4
+ Revision: 429662
- new release
- rediff patches

* Tue May 28 2013 tv <tv> 2.7.3-8.mga4
+ Revision: 429649
- make docs readable by !root...

* Sun Jan 13 2013 umeabot <umeabot> 2.7.3-7.mga3
+ Revision: 378425
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Aug 06 2012 luigiwalser <luigiwalser> 2.7.3-6.mga3
+ Revision: 278990
- rebuild for libffi

* Mon Jul 30 2012 tv <tv> 2.7.3-5.mga3
+ Revision: 276242
- rebuild for db-5.3

* Tue Jul 10 2012 luigiwalser <luigiwalser> 2.7.3-4.mga3
+ Revision: 269231
- add patch from rhel6 via mdv to verify that XML_SetHashSalt is in expat

* Mon Jun 18 2012 obgr_seneca <obgr_seneca> 2.7.3-3.mga3
+ Revision: 261795
- use system expat and ffi instead of bundled ones
- clean BRs
- Added patch for CVE-2011-4944 (Mga Bug #5843)

* Thu Jun 14 2012 tv <tv> 2.7.3-2.mga3
+ Revision: 260509
- build with db5.2

* Sun Apr 22 2012 wally <wally> 2.7.3-2.mga2
+ Revision: 232502
- fix _curses module build (mga#5524)

* Thu Apr 19 2012 fwang <fwang> 2.7.3-1.mga2
+ Revision: 231756
- update file list
- use xz tarball
- update file list
- new version 2.7.3

  + guillomovitch <guillomovitch>
    - spec cleanup
    - rename distribution-specific documentation file to README.mga

* Mon Dec 05 2011 fwang <fwang> 2.7.2-3.mga2
+ Revision: 176928
- add upstream patch to recognize gdbm 1.9 magic value
- build with gdbm
- rebuild for new gdbm

* Fri Sep 02 2011 tv <tv> 2.7.2-2.mga2
+ Revision: 137806
- make the huge doc subpackage be noarch

* Sat Jul 02 2011 fwang <fwang> 2.7.2-1.mga2
+ Revision: 117293
- br valgrind-devel
- new version 2.7.2

* Mon May 23 2011 misc <misc> 2.7.1-6.mga1
+ Revision: 100214
- do not duplicate line wth test ( especially since this mean some of them will be out of sync
- disable test_urllib2, as the test added by latest CVE do not seems to work ( at least on
  our builder bot ) and we are soon releasing

  + dmorgan <dmorgan>
    - P26: security fix for CVE-2011-1521

* Thu May 05 2011 misc <misc> 2.7.1-5.mga1
+ Revision: 95183
- reuse mandriva patch made by Guillomovitch to fix mga#481

* Thu May 05 2011 misc <misc> 2.7.1-4.mga1
+ Revision: 95087
- update patch to make sure that semaphore are enabled ( 2nd attempt at bug 481 )

* Tue Apr 26 2011 wally <wally> 2.7.1-3.mga1
+ Revision: 91819
- fix desktop file names (mga#954)
- drop buildroot definition

* Thu Apr 14 2011 misc <misc> 2.7.1-2.mga1
+ Revision: 85334
- add fix for mageia bug 481, patch by Panos Christeas, to force
  detection of sem_open

  + rtp <rtp>
    - fix ffi check on mips
    - regenerate IN.py/DLFCN.py/... at build time to make sure they're fine on current arch
    - fix arch detection
    - disable float test on arm

* Sun Jan 16 2011 misc <misc> 2.7.1-1.mga1
+ Revision: 20497
- built without db2 support ( was dropped from fedora, and i do not really know
  why we keep it )
- remove old compatibility macros

  + blino <blino>
    - imported package python


* Mon Nov 29 2010 Funda Wang <fwang@mandriva.org> 2.7.1-1mdv2011.0
+ Revision: 602975
- drop merged CVE patch
- X11-devel not required
- New version 2.7.1

* Thu Nov 04 2010 Funda Wang <fwang@mandriva.org> 2.7-8mdv2011.0
+ Revision: 593073
- fix conflicts

  + Michael Scherer <misc@mandriva.org>
    - revert patch as it was not applied upstream first, and as it change the API

* Wed Nov 03 2010 Paulo Andrade <pcpa@mandriva.com.br> 2.7-7mdv2011.0
+ Revision: 593024
- Add http://bugs.python.org/issue7689 correction

  + Funda Wang <fwang@mandriva.org>
    - python-devel not needed

* Sun Oct 31 2010 Funda Wang <fwang@mandriva.org> 2.7-6mdv2011.0
+ Revision: 591160
- more linkage fix
- BR python-devel for now
- link against dl also
- fix module link of ctypes
- move Makefile and pyconfig into main pkg as required by sysconfig.py

* Sat Oct 30 2010 Oden Eriksson <oeriksson@mandriva.com> 2.7-5mdv2011.0
+ Revision: 590456
- P23: security fix for CVE-2010-3493
- P24: security fix for CVE-2010-3492

* Sat Oct 30 2010 Anssi Hannula <anssi@mandriva.org> 2.7-4mdv2011.0
+ Revision: 590326
- apply current devel library naming policy to smoothen upgrades

* Fri Oct 29 2010 Michael Scherer <misc@mandriva.org> 2.7-3mdv2011.0
+ Revision: 590288
- add a provides on python(abi), macro taken by fedora, proposal by anssi to have a automated requires on the python version

* Fri Oct 29 2010 Funda Wang <fwang@mandriva.org> 2.7-2mdv2011.0
+ Revision: 589919
- really use correct patch from fedora
- add fedora patch to fix lib64 detecting

* Fri Oct 29 2010 Michael Scherer <misc@mandriva.org> 2.7-1mdv2011.0
+ Revision: 589889
- fix the test list exception
- fix the test name that should be disabled
- disable test_get_outputs, seems it requires that python 2.7 is installed on build host
- disable test_getsitepackages as it fail due to one of our patch, I need to fix the test
- update to 2.7
- enable wide unicode support ( fix mdv#48570 )
- remove patch applied upstream ( tcl 8.6, pymalloc, d 4.8 )
- remove patch no longer needed ( ctypes linkage )
- remove patch deviating too much from upstream and not accepted yet ( xz )
- update lib6' patch
- add patch for support of new autoconf
- reenable tests that were previously disable, as this doesn't cause problem anymore

* Wed Aug 25 2010 Funda Wang <fwang@mandriva.org> 2.6.6-1mdv2011.0
+ Revision: 573088
- new version 2.6.6

* Wed Jul 14 2010 Oden Eriksson <oeriksson@mandriva.com> 2.6.5-4mdv2011.0
+ Revision: 553383
- bump release
- P21: security fix for CVE-2010-2089
- note that P19 does NOT solve CVE-2008-5983, it's just a new api
  developers can use to fix similar problems, will be added in 2.6.6

  + Funda Wang <fwang@mandriva.org>
    - add upstream patch to build with 4.8
    - add patches fixing CVE-2008-5983 and CVE-2010-1634

* Mon Apr 05 2010 Funda Wang <fwang@mandriva.org> 2.6.5-2mdv2010.1
+ Revision: 531712
- rebuild for new openssl

  + Michael Scherer <misc@mandriva.org>
    - add a BuildConflicts for failling test

* Sat Mar 20 2010 Michael Scherer <misc@mandriva.org> 2.6.5-1mdv2010.1
+ Revision: 525430
- add exception for test_distutils ( as it requires python-devel )
- update to 2.6.5
- remove patch for CVE-2009-3560, merged upstream
- remove patch from Fedora, not approved upstream
- clean test exceptions
- update linkage patch for python 2.6.5

  + Oden Eriksson <oeriksson@mandriva.com>
    - rebuilt against openssl-0.9.8m

* Sat Jan 30 2010 Funda Wang <fwang@mandriva.org> 2.6.4-6mdv2010.1
+ Revision: 498510
- add patches from fedora to have it built and work with db4.8

* Mon Jan 25 2010 Michael Scherer <misc@mandriva.org> 2.6.4-5mdv2010.1
+ Revision: 496309
- re-add _bsddb.so, as it doesn't support db4.8, spotted by bogdano

* Sun Jan 17 2010 Michael Scherer <misc@mandriva.org> 2.6.4-4mdv2010.1
+ Revision: 492596
- link python with ncursesw, to fix canto crashing

* Sun Jan 10 2010 Oden Eriksson <oeriksson@mandriva.com> 2.6.4-3mdv2010.1
+ Revision: 488613
- P18: security fix for CVE-2009-3560

* Thu Dec 31 2009 Funda Wang <fwang@mandriva.org> 2.6.4-2mdv2010.1
+ Revision: 484292
- 2.6.4 docs
- rebuild for db 4.8

* Tue Oct 27 2009 Michael Scherer <misc@mandriva.org> 2.6.4-1mdv2010.0
+ Revision: 459569
- update doc
- update to latest version of python

* Tue Oct 06 2009 Michael Scherer <misc@mandriva.org> 2.6.3-1mdv2010.0
+ Revision: 454344
- disable test_distutils, as the test requires python-devel to be installed
- new bugfix release

* Sun Aug 23 2009 Oden Eriksson <oeriksson@mandriva.com> 2.6.2-4mdv2010.0
+ Revision: 419988
- bump release
- P18: security fix related to CVE-2009-2625

* Sat Jul 11 2009 Funda Wang <fwang@mandriva.org> 2.6.2-2mdv2010.0
+ Revision: 394776
- use -lpthread rather than -pthread

* Sat Jul 04 2009 Funda Wang <fwang@mandriva.org> 2.6.2-1mdv2010.0
+ Revision: 392298
- fix libdir
- fix /usr/lib
- fix typo
- fix desktop file
- Update linkage patch
- link on stdc++ is not needed, and it causes wrong link order
- update docs
- New version 2.6.2
- gdbm problem solved upstream
- rediff glibc and format string patch

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - no need to own subdirs of already owned dirs
    - ensure arch-independant tree is owned

  + Michael Scherer <misc@mandriva.org>
    - patch cleaning

* Sun Apr 12 2009 Gustavo De Nardin <gustavodn@mandriva.com> 2.6.1-6mdv2009.1
+ Revision: 366460
- P16: plural-fix, from Fedora, fixes gettext.py parsing of Plural-Forms:
  header (mdv bugs #49475, #44088)

* Wed Mar 04 2009 Gustavo De Nardin <gustavodn@mandriva.com> 2.6.1-5mdv2009.1
+ Revision: 348705
- fixed current UTF-8 proper name in locale.py, which fixes mdv bug #48158

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - add xz support to distutils (P14)

* Tue Feb 24 2009 Michael Scherer <misc@mandriva.org> 2.6.1-4mdv2009.1
+ Revision: 344595
- fix bug #47803, work around a urpmi behavior, idea from
  frederic himpe.

* Mon Jan 26 2009 Michael Scherer <misc@mandriva.org> 2.6.1-3mdv2009.1
+ Revision: 333792
- remove duplicated file from python packages

* Mon Jan 26 2009 Funda Wang <fwang@mandriva.org> 2.6.1-2mdv2009.1
+ Revision: 333679
- add back python-base versioned provides, as our rpm dep finder loves it

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - disable pymalloc when running under valgrind to make debugging with valgrind
      easier (P13)

* Tue Jan 06 2009 Jérôme Soyer <saispo@mandriva.org> 2.6.1-1mdv2009.1
+ Revision: 325462
- New upstream release
- New upstream release

* Sat Dec 27 2008 Adam Williamson <awilliamson@mandriva.org> 2.6-2mdv2009.1
+ Revision: 320034
- version the python-base obsolete
- don't require python-base since it doesn't exist any more

* Wed Dec 24 2008 Michael Scherer <misc@mandriva.org> 2.6-1mdv2009.1
+ Revision: 318324
- upgrade to python 2.6
- disable bytecode by default
- removal of python-base separation
- rediff and remove old patch
- add patch for ctypes format string error

* Fri Dec 19 2008 Adam Williamson <awilliamson@mandriva.org> 2.5.2-8mdv2009.1
+ Revision: 316264
- br db4-devel < 4.7 because it won't build against 4.7

* Fri Dec 19 2008 Michael Scherer <misc@mandriva.org> 2.5.2-7mdv2009.1
+ Revision: 316009
- add patch to build with new gcc check
- fix for new rpm, need to set the patch number

* Fri Dec 05 2008 Adam Williamson <awilliamson@mandriva.org> 2.5.2-6mdv2009.1
+ Revision: 310350
- rebuild for new tcl
- add tcl86.patch (fix for tcl 8.6)

  + Michael Scherer <misc@mandriva.org>
    - revert to 2.5.1 in svn for tcl/tk upgrade
    - obsoletes python-base
    - removal of the separation python/python-base
    - disable bytecode by default
    - update to python 2.6
    - remove all patchs applied upstream
    - rediff some patch ( mandriva detection, lib64 )

* Thu Sep 18 2008 Frederik Himpe <fhimpe@mandriva.org> 2.5.2-5mdv2009.0
+ Revision: 285713
- Add patch fixing security problem CVE-2008-4108

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - change %%patch to %%patch0 as %%patch is now a macro for rpm5

* Mon Aug 25 2008 Michael Scherer <misc@mandriva.org> 2.5.2-4mdv2009.0
+ Revision: 275801
- remove some test that fail, i have no time to investigate, but I need to update for security before release
- add patch for security fix of MDVSA-2008:163, fix for CVE-2008-1679, CVE-2008-2315, CVE-2008-2316, CVE-2008-3142, CVE-2008-3143 and CVE-2008-3144, fix bug #42305

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Tue Apr 15 2008 Gustavo De Nardin <gustavodn@mandriva.com> 2.5.2-3mdv2009.0
+ Revision: 194215
- security fix for Python-2.5.2's CVE-2008-1721

* Sat Mar 08 2008 Funda Wang <fwang@mandriva.org> 2.5.2-2mdv2008.1
+ Revision: 182067
- fix bug#9482, otherwise it reports redhat on mandriva system

* Wed Feb 27 2008 Michael Scherer <misc@mandriva.org> 2.5.2-1mdv2008.1
+ Revision: 175794
- make rpmlint happy, has the application are now in another rpm
- update to 2.5.2, bugfixs release
- rediff some patch

* Thu Jan 31 2008 Michael Scherer <misc@mandriva.org> 2.5.1-10mdv2008.1
+ Revision: 160818
- add patch for CVE-2007-4965 ( interget overflow in imageop ), fix bug #CVE-2007-4965
- add patch8, to reduce number of wakeup, come from fedora and upstream python, close #36743

* Wed Jan 02 2008 Götz Waschk <waschk@mandriva.org> 2.5.1-9mdv2008.1
+ Revision: 140361
- build bsddb module (bug #36317)

* Sat Dec 22 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.5.1-8mdv2008.1
+ Revision: 137221
- order prefix on profile scriptlets

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Fri Dec 21 2007 Oden Eriksson <oeriksson@mandriva.com> 2.5.1-7mdv2008.1
+ Revision: 136346
- rebuilt against new build deps

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - no executable bit on profile scriptlet

  + David Walluck <walluck@mandriva.org>
    - move README.mdk creation from %%install to %%prep
    - escape HOME variable and use macros in README.mdk

* Thu Sep 13 2007 Michael Scherer <misc@mandriva.org> 2.5.1-5mdv2008.0
+ Revision: 85044
- split tkinter in two, so idle is not installed by default
- fix menu for documentation ( bug #33441 )

* Fri Sep 07 2007 Anssi Hannula <anssi@mandriva.org> 2.5.1-4mdv2008.0
+ Revision: 82050
- rebuild for new soname of tcl

* Wed Sep 05 2007 Michael Scherer <misc@mandriva.org> 2.5.1-3mdv2008.0
+ Revision: 79761
- rebuild for new rpm-mandriva-setup

  + Thierry Vignaud <tv@mandriva.org>
    - kill desktop-file-validate's 'warning: key "Encoding" in group "Desktop Entry" is deprecated'

* Thu Aug 23 2007 Thierry Vignaud <tv@mandriva.org> 2.5.1-2mdv2008.0
+ Revision: 69368
- kill ldconfig require as requested by pixel
- kill file require

* Tue May 15 2007 Austin Acton <austin@mandriva.org> 2.5.1-1mdv2008.0
+ Revision: 27079
- buildrequires emacs

  + Michael Scherer <misc@mandriva.org>
    - update to 2.5.1


* Tue Dec 12 2006 Michael Scherer <misc@mandriva.org> 2.5-4mdv2007.0
+ Revision: 95126
- do not packages file twice in python and python-base ( error in python-2.4-base.list )
- rebuild with zlib, fix #27624 ( do not know why it happened in the first place )
- disable test that do not work, will see later why ( as they worked 2 weeks ago )
- add a comment to fix syntax highligthing with vim

* Mon Dec 11 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.5-3mdv2007.1
+ Revision: 94725
- 2.5-3mdv
- Merge from CS3-branch: ppc64 is a lib64 platform

* Tue Nov 28 2006 Michael Scherer <misc@mandriva.org> 2.5-2mdv2007.1
+ Revision: 87754
- adjust buildrequires, and bump release
- adjust tests :
  remove test_shutil as it fail in iurt ( remove /tmp/, i will have to take a closer look )
  reenable test_minidom, as it now work

* Tue Nov 28 2006 Michael Scherer <misc@mandriva.org> 2.5-1mdv2007.1
+ Revision: 87734
- disable test as they do not work in the buildbot. Let's move forward.
- try another workaround to make it compiles in buildbot, and rerun test in verbose mode if failed.
- andreas's suggestion, try a different TMP and TMPDIR, and be sure that it exist
- do not set TMP to /tmp, as it may cause issue with automated rebuilding
- Remove the other icons too, and remove the file from svn
- remove Icon, as it break repsys like this :
  error: Unable to open icon /home/misc/rpm/SOURCES/python-logo.xpm: No such file or directory
  error: query of specfile /tmp/tmp7KbWra/python.spec failed, can't parse
- replace python-ctypes and python-elementtree packages. No need for sqlite,
  we have a old version.
- add missing buildRequires, sqlite3-devel, now bundled with python 2.5
- add missing tarball
- update to python 2.5 ( not finished, i need to add some conflicts/obsoletes/provides )
- unzip patch
- Import python

